@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 
+"""
 #   Copyright (C) 2017 Ludovic Rousseau <ludovic.rousseau@free.fr>
 #
 # This file is free software; you can redistribute it and/or modify it
@@ -15,8 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
+"""
 
-from __future__ import print_function
 
 import PyKCS11
 
