@@ -1,15 +1,18 @@
-# -*- coding: utf-8 -*-
+# pylint: disable=missing-module-docstring
+# pylint: disable=missing-class-docstring
+# pylint: disable=missing-function-docstring
 
-import unittest
-from PyKCS11 import PyKCS11
-import platform
-import shutil
 import gc
 import os
-
+import platform
+import shutil
+import unittest
 from pathlib import Path
 from tempfile import TemporaryDirectory
 
+from PyKCS11 import PyKCS11
+
+
 class TestUtil(unittest.TestCase):
     def setUp(self):
         self.pkcs11 = PyKCS11.PyKCS11Lib()
@@ -17,13 +20,12 @@ class TestUtil(unittest.TestCase):
         self.lib1_name = os.environ["PYKCS11LIB"]
         # create a tmp copy of the main lib
         # to use as a different library in tests
-        self.lib2_name = str(Path(self.tmpdir.name) /
-                             Path(self.lib1_name).name)
+        self.lib2_name = str(Path(self.tmpdir.name) / Path(self.lib1_name).name)
         shutil.copy(self.lib1_name, self.tmpdir.name)
 
     def tearDown(self):
         del self.pkcs11
-        if platform.system() != 'Windows':
+        if platform.system() != "Windows":
             self.tmpdir.cleanup()
         del self.tmpdir
         del self.lib1_name
@@ -62,27 +64,27 @@ class TestUtil(unittest.TestCase):
         # _loaded_libs is shared across all instances
         # check the value in self.pkcs11
         self.assertEqual(len(self.pkcs11._loaded_libs), 2)
-        lib1 = PyKCS11.PyKCS11Lib() # unload lib1
+        lib1 = PyKCS11.PyKCS11Lib()  # unload lib1
         self.assertEqual(len(self.pkcs11._loaded_libs), 1)
-        lib2 = PyKCS11.PyKCS11Lib() # unload lib2
+        lib2 = PyKCS11.PyKCS11Lib()  # unload lib2
         self.assertEqual(len(self.pkcs11._loaded_libs), 0)
 
     def test_invalid_load(self):
-        # Library not found
+        # Library not found
         lib = "nolib"
         with self.assertRaises(PyKCS11.PyKCS11Error) as cm:
             self.pkcs11.load(lib)
         the_exception = cm.exception
         self.assertEqual(the_exception.value, -1)
         self.assertEqual(the_exception.text, lib)
-        self.assertEqual(str(the_exception), "Load (%s)" % lib)
+        self.assertEqual(str(the_exception), f"Load ({lib})")
         self.assertEqual(len(self.pkcs11._loaded_libs), 0)
 
         # C_GetFunctionList() not found
-        if platform.system() == 'Linux':
+        if platform.system() == "Linux":
             # GNU/Linux
             lib = "libc.so.6"
-        elif platform.system() == 'Darwin':
+        elif platform.system() == "Darwin":
             # macOS
             lib = "/usr/lib/libSystem.B.dylib"
         else:
@@ -94,8 +96,7 @@ class TestUtil(unittest.TestCase):
         the_exception = cm.exception
         self.assertEqual(the_exception.value, -4)
         self.assertEqual(the_exception.text, lib)
-        self.assertEqual(str(the_exception),
-            "C_GetFunctionList() not found (%s)" % lib)
+        self.assertEqual(str(the_exception), f"C_GetFunctionList() not found ({lib})")
         self.assertEqual(len(self.pkcs11._loaded_libs), 0)
 
         # try to load the improper lib another time
@@ -104,8 +105,7 @@ class TestUtil(unittest.TestCase):
         the_exception = cm.exception
         self.assertEqual(the_exception.value, -4)
         self.assertEqual(the_exception.text, lib)
-        self.assertEqual(str(the_exception),
-            "C_GetFunctionList() not found (%s)" % lib)
+        self.assertEqual(str(the_exception), f"C_GetFunctionList() not found ({lib})")
         self.assertEqual(len(self.pkcs11._loaded_libs), 0)
 
         # finally, load a valid library
@@ -131,16 +131,16 @@ class TestUtil(unittest.TestCase):
     def test_unload(self):
         self.pkcs11.load().unload()
         # no pkcs11dll_filename should remain after unload
-        self.assertFalse(hasattr(self.pkcs11, "pkcs11dll_filename"))
+        self.assertIsNone(self.pkcs11.pkcs11dll_filename)
 
         self.pkcs11.load()
         self.openSession(self.pkcs11)
         # one library has been loaded
         self.assertEqual(len(self.pkcs11._loaded_libs), 1)
-        self.assertTrue(hasattr(self.pkcs11, "pkcs11dll_filename"))
+        self.assertIsNotNone(self.pkcs11.pkcs11dll_filename)
 
         self.pkcs11.unload()
         gc.collect()
         # manually unloaded the library using gc.collect()
         self.assertEqual(len(self.pkcs11._loaded_libs), 0)
-        self.assertFalse(hasattr(self.pkcs11, "pkcs11dll_filename"))
+        self.assertIsNone(self.pkcs11.pkcs11dll_filename)
